#
# spec file for package snowmix
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define srcname Snowmix
%define namegui snowmixgui
Name:           snowmix
Version:        0.5.1
Release:        pm153.2.5
Summary:        Live Video Mixer
License:        GPL-3.0
Group:          Productivity/Multimedia/Video/Editors and Convertors
URL:            http://snowmix.sourceforge.net/
Source0:        https://sourceforge.net/projects/snowmix/files/%{srcname}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE dir.patch avvissu@yandex.ru -- Change symbolic links
Patch0:         Snowmix-0.5.1_dir.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  freeglut-devel
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(osmesa)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(sdl)
BuildRequires:  pkgconfig(tcl)
BuildRequires:  update-desktop-files
Requires:       gstreamer-plugins-bad
Requires:       gstreamer-plugins-base
Requires:       gstreamer-plugins-good
Requires:       gstreamer-plugins-libav
Requires:       gstreamer-plugins-ugly
Requires:       gstreamer-utils

%description
Snowmix is a Swiss army knife tool for mixing live and recorded video and
audio feeds. It supports 2D and 3D clipping, scaling and transparent
overlay of video, png graphics and text. It supports animation of video,
images and texts through native commands changing scale, placement,
transparency and rotation. Animation and actions can also be controlled
through native scripting and an embedded Tcl interpreter. Snowmix is
designed for control over low bandwidth links and can work as a standalone
CLI based program. Control over both CLI and a TCP connections.

%prep
%setup -q -n %{srcname}-%{version}
%patch0 -p1

%build
export LIBS="$(pkg-config --libs tcl gobject-2.0)"
autoreconf -fiv

# Use datadir instead of libdir: libraries are mostly written in tcl
%configure \
    --enable-snowmixgui \
    --enable-snowmixosmesa \
    --enable-snowmixx11 \
    --enable-snowmixglu \
    --enable-snowmixglut \
    --libdir=%{_datadir} \
    --libexecdir=%{_datadir}

make %{?_smp_mflags}

%install
%make_install tcldir="%{_datadir}/%{srcname}-%{version}/tcl"

install -d %{buildroot}%{_sysconfdir}/profile.d
cat<<EOF > "%{buildroot}%{_sysconfdir}/profile.d/%{name}.sh"
if [ -f %{_bindir}/%{name} ]; then
export SNOWMIX="%{_datadir}/%{srcname}-%{version}"
fi
EOF

%fdupes -s %{buildroot}%{_datadir}

%files
%license COPYING
%doc AUTHORS ChangeLog ReleaseNotes
%{_bindir}/av_output2dummy
%{_bindir}/av_output2screen
%{_bindir}/av_output2tcp_server
%{_bindir}/gstreamer-settings
%{_bindir}/input2feed
%{_bindir}/output2dummy
%{_bindir}/output2file
%{_bindir}/output2rtp
%{_bindir}/output2screen
%{_bindir}/output2screen-auto
%{_bindir}/rtsp2feed
%{_bindir}/rtsp2feed2
%{_bindir}/snowaudio.tcl
%{_bindir}/snowmix
%{_bindir}/snowmix-settings
%{_bindir}/snowmix_demo
%{_bindir}/snowmixgui
%{_bindir}/snowoutput.tcl
%{_bindir}/snowrelay.tcl
%{_bindir}/snowscene.tcl
%{_bindir}/v4l2input2feed
%{_datadir}/%{srcname}-%{version}
%config %{_sysconfdir}/profile.d/%{name}.sh

%changelog
* Fri May 17 2019 Luigi Baldoni <aloisio@gmx.com>
- Fixed tumbleweed build
- Spec cleanup
* Sun Dec 13 2015 avvissu@yandex.ru
- Initial build
